# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import Command_pb2 as Command__pb2
import Event_pb2 as Event__pb2
import worm_pb2 as worm__pb2


class WormServiceStub(object):
  """service definition.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.IssueCommand = channel.unary_unary(
        '/WormService/IssueCommand',
        request_serializer=Command__pb2.Command.SerializeToString,
        response_deserializer=worm__pb2.Response.FromString,
        )
    self.Subscribe = channel.unary_stream(
        '/WormService/Subscribe',
        request_serializer=worm__pb2.Subscription.SerializeToString,
        response_deserializer=Event__pb2.Event.FromString,
        )


class WormServiceServicer(object):
  """service definition.
  """

  def IssueCommand(self, request, context):
    """Issue a Command
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Subscribe(self, request, context):
    """Subscribe, receive Events
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WormServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'IssueCommand': grpc.unary_unary_rpc_method_handler(
          servicer.IssueCommand,
          request_deserializer=Command__pb2.Command.FromString,
          response_serializer=worm__pb2.Response.SerializeToString,
      ),
      'Subscribe': grpc.unary_stream_rpc_method_handler(
          servicer.Subscribe,
          request_deserializer=worm__pb2.Subscription.FromString,
          response_serializer=Event__pb2.Event.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'WormService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Command.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Command.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n\rCommand.proto\"\x98\x01\n\x07\x43ommand\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12%\n\x07\x63ontext\x18\x04 \x01(\x0e\x32\x14.Command.ContextType\"<\n\x0b\x43ontextType\x12\x0b\n\x07\x44\x45SKTOP\x10\x00\x12\x07\n\x03WEB\x10\x01\x12\n\n\x06MOBILE\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x42\x08Z\x06golangb\x06proto3')
)



_COMMAND_CONTEXTTYPE = _descriptor.EnumDescriptor(
  name='ContextType',
  full_name='Command.ContextType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DESKTOP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEB', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=110,
  serialized_end=170,
)
_sym_db.RegisterEnumDescriptor(_COMMAND_CONTEXTTYPE)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Command.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='Command.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='Command.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='Command.context', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMAND_CONTEXTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=170,
)

_COMMAND.fields_by_name['context'].enum_type = _COMMAND_CONTEXTTYPE
_COMMAND_CONTEXTTYPE.containing_type = _COMMAND
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'Command_pb2'
  # @@protoc_insertion_point(class_scope:Command)
  ))
_sym_db.RegisterMessage(Command)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\006golang'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: worm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Event_pb2 as Event__pb2
import Command_pb2 as Command__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='worm.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n\nworm.proto\x1a\x0b\x45vent.proto\x1a\rCommand.proto\"7\n\x08Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x03 \x01(\x05\"\x1d\n\x0cSubscription\x12\r\n\x05topic\x18\x01 \x01(\t2\\\n\x0bWormService\x12%\n\x0cIssueCommand\x12\x08.Command\x1a\t.Response\"\x00\x12&\n\tSubscribe\x12\r.Subscription\x1a\x06.Event\"\x00\x30\x01\x42\x08Z\x06golangb\x06proto3')
  ,
  dependencies=[Event__pb2.DESCRIPTOR,Command__pb2.DESCRIPTOR,])




_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='Response.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='Response.code', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=97,
)


_SUBSCRIPTION = _descriptor.Descriptor(
  name='Subscription',
  full_name='Subscription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='Subscription.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=128,
)

DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Subscription'] = _SUBSCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'worm_pb2'
  # @@protoc_insertion_point(class_scope:Response)
  ))
_sym_db.RegisterMessage(Response)

Subscription = _reflection.GeneratedProtocolMessageType('Subscription', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTION,
  __module__ = 'worm_pb2'
  # @@protoc_insertion_point(class_scope:Subscription)
  ))
_sym_db.RegisterMessage(Subscription)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\006golang'))

_WORMSERVICE = _descriptor.ServiceDescriptor(
  name='WormService',
  full_name='WormService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=130,
  serialized_end=222,
  methods=[
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='WormService.IssueCommand',
    index=0,
    containing_service=None,
    input_type=Command__pb2._COMMAND,
    output_type=_RESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='WormService.Subscribe',
    index=1,
    containing_service=None,
    input_type=_SUBSCRIPTION,
    output_type=Event__pb2._EVENT,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORMSERVICE)

DESCRIPTOR.services_by_name['WormService'] = _WORMSERVICE

# @@protoc_insertion_point(module_scope)



try:
    import _pickle as pickle
except ImportError:
    import cPickle as pickle
from os.path import abspath, dirname, join


def get_schema():
    with open(join(dirname(abspath(__file__)), 'actions.p'), 'rb') as fp:
        schema = pickle.load(fp)

    return schema


def get_events():
    with open(join(dirname(abspath(__file__)), 'events.p'), 'rb') as fp:
        events = pickle.load(fp)

    return events


def get_version():
    schema = get_schema()
    version = schema['_version']

    return version


__version__ = get_version()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Msg.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Msg.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n\tMsg.proto\"g\n\x03Msg\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\x03\x12\n\n\x02to\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12\x0f\n\x07payload\x18\x05 \x01(\t\x12\x0b\n\x03jwt\x18\x06 \x01(\tB>\n\x17\x63om.boundlessgeo.schemaB\nMessagePbfZ\x17\x63om.boundlessgeo.schemab\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MSG = _descriptor.Descriptor(
  name='Msg',
  full_name='Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context', full_name='Msg.context', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='correlationId', full_name='Msg.correlationId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to', full_name='Msg.to', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='Msg.action', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='Msg.payload', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jwt', full_name='Msg.jwt', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['Msg'] = _MSG

Msg = _reflection.GeneratedProtocolMessageType('Msg', (_message.Message,), dict(
  DESCRIPTOR = _MSG,
  __module__ = 'Msg_pb2'
  # @@protoc_insertion_point(class_scope:Msg)
  ))
_sym_db.RegisterMessage(Msg)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\027com.boundlessgeo.schemaB\nMessagePbfZ\027com.boundlessgeo.schema'))
# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

with open('boundlessgeo_schema/README.rst', 'r') as inp:
    LONG_DESCRIPTION = inp.read()


setup(
    name='boundlessgeo-schema',
    description='schema for boundlessgeo actions',
    version=__import__('boundlessgeo_schema').get_version(),
    author='Boundless Spatial',
    author_email='contact@boundlessgeo.com',
    url='https://github.com/boundlessgeo/schema',
    long_description=LONG_DESCRIPTION,
    license='Public Domain',
    keywords=['schema', 'json', 'dict'],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
        classifiers=[
        'Topic :: Utilities',
        'Intended Audience :: System Administrators',
        'Environment :: Web Environment',
        'License :: OSI Approved :: Apache Software License',
        'Development Status :: 3 - Alpha',
        'Operating System :: Other OS',
    ],
    install_requires=[
        'protobuf==3.3.0',
    ]
)
